#include "ImageLoader.h"
#include <stdlib.h>

static const char *imageFiles[] =
{
	DATA_PREFIX "table.png",
	DATA_PREFIX "unsetball.png",
	DATA_PREFIX "cueball.png",
	DATA_PREFIX "1ball.png",
	DATA_PREFIX "2ball.png",
	DATA_PREFIX "3ball.png",
	DATA_PREFIX "4ball.png",
	DATA_PREFIX "5ball.png",
	DATA_PREFIX "6ball.png",
	DATA_PREFIX "7ball.png",
	DATA_PREFIX "8ball.png",
	DATA_PREFIX "9ball.png",
	DATA_PREFIX "10ball.png",
	DATA_PREFIX "11ball.png",
	DATA_PREFIX "12ball.png",
	DATA_PREFIX "13ball.png",
	DATA_PREFIX "14ball.png",
	DATA_PREFIX "15ball.png",
	DATA_PREFIX "ballshadow.png",
	DATA_PREFIX "top_side.png",
	DATA_PREFIX "topright_side.png",
	DATA_PREFIX "bottomright_side.png",
	DATA_PREFIX "bottom_side.png",
	DATA_PREFIX "bottomleft_side.png",
	DATA_PREFIX "topleft_side.png",
	DATA_PREFIX "hole.png",
	DATA_PREFIX "splashscreen.png",
	DATA_PREFIX "floor.png",
	DATA_PREFIX "tableshadow.png",
	DATA_PREFIX "curplayer_arrow.png",
	DATA_PREFIX "meter_bg.png",
	DATA_PREFIX "meter_bar.png",
	DATA_PREFIX "shootbutton.png",
	DATA_PREFIX "sunktray.png"
};

/* Total number of images */
#define NUM_IMAGES (signed)(sizeof(imageFiles) / sizeof(*imageFiles))

ImageLoader::ImageLoader()
{
	images = new SDL_Surface *[NUM_IMAGES];

	for (Uint16 i = 0; i < NUM_IMAGES; i++)
		images[i] = NULL;
}

ImageLoader::~ImageLoader()
{
	for (Uint16 i = 0; i < NUM_IMAGES; i++)
	{
		if (images[i] != NULL)
			SDL_FreeSurface(images[i]);
	}

	delete [] images;

	images = NULL;
}

SDL_Surface *
ImageLoader::load(Uint16 num, bool alphaChannel)
{
	return load((ImageType)num, alphaChannel);
}

SDL_Surface *
ImageLoader::load(ImageType type, bool alphaChannel)
{
	if (type >= NUM_IMAGES)
		return NULL;

	if (images[type] == NULL)
	{
		SDL_Surface *tempImage;
		SDL_Surface *image;

		tempImage = IMG_Load(imageFiles[type]);

		if (tempImage == NULL)
		{
			fprintf(stderr, "Unable to load graphics file `%s': %s\n",
					imageFiles[type], SDL_GetError());
			exit(1);
		}

		if (alphaChannel)
			image = SDL_DisplayFormatAlpha(tempImage);
		else
			image = SDL_DisplayFormat(tempImage);

		if (image == NULL)
		{
			fprintf(stderr,
					"Unable to convert file `%s' to display format: %s\n",
					imageFiles[type], SDL_GetError());
			exit(1);
		}

		SDL_FreeSurface(tempImage);

		images[type] = image;
	}

	return images[type];
}
